;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "company" "20260424.2111"
  "Modular text completion framework."
  '((emacs    "26.1")
    (posframe "1.5.1"))
  :url "http://company-mode.github.io/"
  :commit "7a636925bf37bc7aabaed70ad9188ab427a9db2a"
  :revdesc "7a636925bf37"
  :keywords '("abbrev" "convenience" "matching")
  :maintainers '(("Dmitry Gutov" . "dmitry@gutov.dev")))
